import { Plugin } from "vue";
import { DynamicModalOptions, VueFinalModalProperty } from "vue-final-modal";
import { Router } from "vue-router";
export type HistoryModalPluginOption = {
    modal: VueFinalModalProperty;
    router: Router;
};
/**
 * 반드시 `setup()` 함수 내에서 호출되어야 한다.
 */
export declare const useHistoryModal: () => HistoryModal;
export interface HistoryModal {
    show(option: DynamicModalOptions, params?: Record<string, unknown>): Promise<void>;
    hide(modalName: string): Promise<void>;
    hideAllModals(): Promise<void>;
    getOpenModalKeys(): string[];
}
/**
 * ```ts
 * createApp(GuideMain)
 *     .use(router)
 *     .use(ModalPlugin)
 *     .use(HistoryModalPlugin, {router, modal: ModalPlugin.modal})
 * ```
 */
export declare const HistoryModalPlugin: Plugin;
/**
 * historyModal 이 열려있으면 router.back() 후 action 을 실행하고,
 * 그렇지 않으면 곧바로 action 을 실행한다.
 * @param historyModal
 * @param router
 * @param action
 */
export declare const closeHistoryModalAndDo: (historyModal: HistoryModal, router: Router, action: () => unknown) => Promise<void>;
